@@ -12,16 +12,12 @@ def parseOptions():
     basename = os.path.basename(sys.argv[0]).rstrip('.py')
     dirname  = os.path.dirname(__file__)
 
-    config_dir  = os.environ['HOME'] + F'/.config/{basename}'
     # config_file = os.environ['HOME']+F'/.config/{basename}.conf'
     config_file = F'/etc/contextualise_ssh_server.conf'
     config_file = F'contextualise_ssh_server.conf'
     log_file    = folder_of_executable + F'/{basename}.log'
     log_file    = ""
 
-    if not os.path.exists(config_dir):
-        os.mkdir(config_dir)
-
     parser = argparse.ArgumentParser(formatter_class=argparse.ArgumentDefaultsHelpFormatter)
 
     parser.add_argument("--verbose",    "-v",   action="count", default=0, help="Verbosity")
